/**
 * @license
 * Copyright Akveo. All Rights Reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 */
import React from 'react';
import { Frame } from './type';
export interface MeasureElementProps<P = any> {
    onMeasure: (frame: Frame) => void;
    children: React.ReactElement<P>;
}
export declare type MeasuringElement<P = any> = React.ReactElement;
/**
 * Measures child element size and it's screen position asynchronously.
 * Returns measure result in `onMeasure` callback.
 *
 * Usage:
 *
 * const onMeasure = (frame: Frame): void => {
 *   const { x, y } = frame.origin;
 *   const { width, height } = frame.size;
 *   ...
 * };
 *
 * <MeasureElement onMeasure={onMeasure}>
 *   <ElementToMeasure />
 * </MeasureElement>
 */
export declare const MeasureElement: (props: MeasureElementProps<any>) => MeasuringElement<any>;
